@@ -1,10 +1,10 @@
 package Proch::N50;
-#ABSTRACT: a small module to calculate N50 (total size, and total number of sequences) for a FASTA or FASTQ file. It's small and without dependencies.
+#ABSTRACT: a small module to calculate N50 (total size, and total number of sequences) for a FASTA or FASTQ file. It's easy to install, with minimal dependencies.
 
 use 5.014;
 use warnings;
 
-$Proch::N50::VERSION = '0.08';
+$Proch::N50::VERSION = '0.09';
 
 use JSON::PP;
 use FASTX::Reader;
@@ -25,12 +25,13 @@ sub getStats {
     $answer->{N50}    = undef;
 
     # Check file existence
+# uncoverable condition right
     if ( !-e "$file" and $file ne '-' ) {
         $answer->{status}  = 0;
         $answer->{message} = "Unable to find <$file>";
     }
 
-    
+
 
     # Return failed status if file not found or not readable
     if ( $answer->{status} == 0 ) {
@@ -110,8 +111,8 @@ sub getN50 {
     my ($file) = @_;
     my $stats = getStats($file);
 
-    # Verify status and return
-    # uncoverable branch false
+# Verify status and return
+# uncoverable branch false
     if ( $stats->{status} ) {
         return $stats->{N50};
     } else {
@@ -124,8 +125,8 @@ sub jsonStats {
   my $stats = getStats($file,  'JSON');
 
 
-  # Return JSON object if getStats() was able to reduce one
-  # uncoverable branch false
+# Return JSON object if getStats() was able to reduce one
+# uncoverable branch false
   if ($stats->{status} and $stats->{json}) {
     return $stats->{json}
   } else {
@@ -134,60 +135,62 @@ sub jsonStats {
   }
 }
 
-sub _readfq {
-    # _readfq(): Heng Li's FASTA/FASTQ parser
-    # Parameters:
-    # * FileHandle
-    # * Auxiliary array ref
-    my ( $fh, $aux ) = @_;
-    @$aux = [ undef, 0 ] if ( !(@$aux) );
+# NOW READFQ IS PROVIDED BY: 'FASTX::Reader'
 
-    # Parse FASTA/Q
-    return if ( $aux->[1] );
-    if ( !defined( $aux->[0] ) ) {
-        while (<$fh>) {
-            chomp;
-            # Sequence header > or @
-            if ( substr( $_, 0, 1 ) eq '>' || substr( $_, 0, 1 ) eq '@' ) {
-                $aux->[0] = $_;
-                last;
-            }
-        }
-        if ( !defined( $aux->[0] ) ) {
-            $aux->[1] = 1;
-            return;
-        }
-    }
-
-    my $name = '';
-    if ( defined $_ ) {
-        $name = /^.(\S+)/ ? $1 : '';
-    }
-
-    my $seq = '';
-    my $c;
-    $aux->[0] = undef;
-    while (<$fh>) {
-        chomp;
-        $c = substr( $_, 0, 1 );
-        last if ( $c eq '>' || $c eq '@' || $c eq '+' );
-        $seq .= $_;
-    }
-    $aux->[0] = $_;
-    $aux->[1] = 1 if ( !defined( $aux->[0] ) );
-    return ( $name, $seq ) if ( $c ne '+' );
-    my $qual = '';
-    while (<$fh>) {
-        chomp;
-        $qual .= $_;
-        if ( length($qual) >= length($seq) ) {
-            $aux->[0] = undef;
-            return ( $name, $seq, $qual );
-        }
-    }
-    $aux->[1] = 1;
-    return ( $name, $seq );
-}
+# sub _readfq {
+#     # _readfq(): Heng Li's FASTA/FASTQ parser
+#     # Parameters:
+#     # * FileHandle
+#     # * Auxiliary array ref
+#     my ( $fh, $aux ) = @_;
+#     @$aux = [ undef, 0 ] if ( !(@$aux) );
+#
+#     # Parse FASTA/Q
+#     return if ( $aux->[1] );
+#     if ( !defined( $aux->[0] ) ) {
+#         while (<$fh>) {
+#             chomp;
+#             # Sequence header > or @
+#             if ( substr( $_, 0, 1 ) eq '>' || substr( $_, 0, 1 ) eq '@' ) {
+#                 $aux->[0] = $_;
+#                 last;
+#             }
+#         }
+#         if ( !defined( $aux->[0] ) ) {
+#             $aux->[1] = 1;
+#             return;
+#         }
+#     }
+#
+#     my $name = '';
+#     if ( defined $_ ) {
+#         $name = /^.(\S+)/ ? $1 : '';
+#     }
+#
+#     my $seq = '';
+#     my $c;
+#     $aux->[0] = undef;
+#     while (<$fh>) {
+#         chomp;
+#         $c = substr( $_, 0, 1 );
+#         last if ( $c eq '>' || $c eq '@' || $c eq '+' );
+#         $seq .= $_;
+#     }
+#     $aux->[0] = $_;
+#     $aux->[1] = 1 if ( !defined( $aux->[0] ) );
+#     return ( $name, $seq ) if ( $c ne '+' );
+#     my $qual = '';
+#     while (<$fh>) {
+#         chomp;
+#         $qual .= $_;
+#         if ( length($qual) >= length($seq) ) {
+#             $aux->[0] = undef;
+#             return ( $name, $seq, $qual );
+#         }
+#     }
+#     $aux->[1] = 1;
+#     return ( $name, $seq );
+# }
 
 
 1;
@@ -200,11 +203,11 @@ __END__
 
 =head1 NAME
 
-Proch::N50 - a small module to calculate N50 (total size, and total number of sequences) for a FASTA or FASTQ file. It's small and without dependencies.
+Proch::N50 - a small module to calculate N50 (total size, and total number of sequences) for a FASTA or FASTQ file. It's easy to install, with minimal dependencies.
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -346,7 +349,7 @@ Returns N50, min and max lengths.
 
 =head1 AUTHOR
 
-Andrea Telatin <andrea.telatin@quadram.ac.uk>
+Andrea Telatin <andrea@telatin.com>
 
 =head1 COPYRIGHT AND LICENSE
 
